@@ -135,13 +135,9 @@ class Attribute(object):
 
     def __get__(self, obj, objtype):
         """Gets the value for this attribute on the given object."""
-        # Attributes cannot be used as class properties
         if obj is None:
-            raise AttributeError(
-                "type object '{}' has no attribute '{}'".format(
-                    objtype, self._attribute_name
-                )
-            )
+            # Class attribute; different from the actual value!
+            return self
 
         return obj._attributes.get(self._attribute_name)
 
@@ -382,7 +378,7 @@ class CatalogObjectReference(Attribute):
         corresponding id field are modified.
         """
         if obj is None:
-            return super(CatalogObjectReference, self).__get__(self, obj, objtype)
+            return super(CatalogObjectReference, self).__get__(obj, objtype)
 
         cached_value = obj._attributes.get(self._attribute_name)
         reference_id = getattr(obj, self.id_field)
