@@ -20,12 +20,10 @@ import importlib
 import inspect
 import io
 import itertools
-import json
 import logging
 import os
 import re
 import six
-from six.moves import zip_longest
 import sys
 import time
 from warnings import warn
@@ -39,7 +37,7 @@ except ImportError:
 
 from descarteslabs.client.auth import Auth
 from descarteslabs.client.deprecation import deprecate_func
-from descarteslabs.client.exceptions import ConflictError
+from descarteslabs.client.exceptions import AuthError
 from descarteslabs.client.services.service import Service, ThirdPartyService
 from descarteslabs.common.dotdict import DotDict, DotList
 from descarteslabs.common.services.tasks.constants import (
@@ -82,6 +80,7 @@ class GroupTerminalException(Exception):
     """
     Raised when waiting on a task group that stopped accepting tasks.
     """
+
     pass
 
 
@@ -158,6 +157,20 @@ class Tasks(Service):
         """
         return self._create_namespace()
 
+    def update_credentials(self):
+        """
+        Updates the credentials for the tasks run by this user. It updates the
+        authentication within the user's tasks namespace. If the user invalidates
+        existing credentials and needs to update them with new credentials, you
+        should call this method.
+
+        Note that when you create a new task group, your credentials are
+        automatically updated.
+
+        :return: `True` if successful, `False` otherwise.
+        """
+        return self._create_namespace()
+
     def new_group(
         self,
         function,
@@ -173,7 +186,7 @@ class Tasks(Service):
         include_modules=None,
         include_data=None,
         requirements=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Creates a new task group.
@@ -194,7 +207,7 @@ class Tasks(Service):
             (e.g. `"4Gi"`, `"500MB"`). If no unit is specified it is assumed to be
             in bytes. Default: 2Gi. Maximum: 96Gi.
         :param int maximum_concurrency: The maximum number of tasks to run in
-            parallel. Default: 500. Maximum: 500. If you need higher concurrency
+            parallel. Default: 5. Maximum: 500. If you need higher concurrency
             contact your Descartes Labs customer success representative.
         :param int minimum_concurrency: The minimum number of tasks to run right
             away in parallel. Concurrency is usually scaled up slowly when
@@ -267,18 +280,10 @@ class Tasks(Service):
                 )
                 warn(PICKLE_DEPRECATION_MESSAGE.format(e), FutureWarning)
 
-            try:
-                r = self.session.post("/groups", json=payload)
-            except ConflictError as e:
-                error_message = json.loads(str(e))["message"]
-                if error_message != "namespace is missing authentication":
-                    raise
-
-                if not self._create_namespace():
-                    raise
-
-                r = self.session.post("/groups", json=payload)
+            if not self._create_namespace():
+                raise AuthError("Cannot install credentials for task group")
 
+            r = self.session.post("/groups", json=payload)
             group = r.json()
 
             if bundle_path is not None:
@@ -419,6 +424,87 @@ class Tasks(Service):
             if g.name == name:
                 return g
 
+    def update_group(
+        self,
+        group_id,
+        container_image=None,
+        name=None,
+        cpus=None,
+        gpus=None,
+        memory=None,
+        maximum_concurrency=None,
+        minimum_concurrency=None,
+        minimum_seconds=None,
+        task_timeout=None,
+        **kwargs,
+    ):
+        """
+        Update attributes of a group.
+
+        :param str group_id: The group id.
+        :param str container_image: The optional new location of a docker image
+            to be used for the environment in which the function is executed.
+        :param str name: An optional new name used to later help identify the function.
+        :param int cpus: The optional new number of CPUs requested for a single task. A task
+            might be throttled if it uses more CPU. Maximum: 16.
+        :param int gpus: The optional new number of GPUs requested for a single task. As of
+            right now, a maximum of 1 GPU is supported. Maximum: 1. May not
+            be changed from zero to non-zero or non-zero to zero.
+        :param str memory: The optional new maximum memory requirement for a single task.
+            If a task uses substantially more memory it will be killed. The value
+            should be a string and can use postfixes such as Mi, Gi, MB, GB, etc
+            (e.g. `"4Gi"`, `"500MB"`). If no unit is specified it is assumed to be
+            in bytes.Maximum: 96Gi.
+        :param int maximum_concurrency: The optional new maximum number of tasks to run in
+            parallel. Maximum: 500. If you need higher concurrency
+            contact your Descartes Labs customer success representative.
+        :param int minimum_concurrency: The optional new minimum number of tasks to run right
+            away in parallel. Concurrency is usually scaled up slowly when
+            submitting new tasks. Setting this can mean more immediate processing
+            of this many newly submitted tasks. Note that setting this means the
+            equivalent resources of this many permanently running tasks will be
+            charged to your account while this group is active. Maximum: 4.
+        :param int minimum_seconds: The optional new number of seconds to wait for new tasks
+            before scaling down concurrency, after a task is finished. Maximum: 600.
+        :param int task_timeout: The optional new maximum runtime for a single task in seconds. A
+            task will be killed if it exceeds this limit. Minimum: 10 seconds. Maximum: 24 hours.
+
+        :return: A dictionary representing the updated task group.
+        :rtype: DotDict
+
+        :raises ~descarteslabs.client.exceptions.NotFoundError: Raised if the
+            task group cannot be found.
+        """
+
+        payload = {}
+        if container_image is not None:
+            payload["image"] = container_image
+        if name is not None:
+            payload["name"] = name
+        if cpus is not None:
+            payload["cpu"] = cpus
+        if gpus is not None:
+            payload["gpu"] = gpus
+        if memory is not None:
+            payload["mem"] = str(memory)
+        if maximum_concurrency is not None:
+            payload["maximum_concurrency"] = maximum_concurrency
+        if minimum_concurrency is not None:
+            payload["minimum_concurrency"] = minimum_concurrency
+        if minimum_seconds is not None:
+            payload["minimum_seconds"] = minimum_seconds
+        if task_timeout is not None:
+            payload["worker_timeout"] = task_timeout
+
+        payload.update(kwargs)
+
+        r = self.session.patch(
+            "/groups/{}".format(group_id),
+            json=payload,
+        )
+        r.raise_for_status()
+        return DotDict(r.json())
+
     def terminate_group(self, group_id):
         """
         Terminates a task group by id. Once a group is terminated, no more tasks
@@ -539,7 +625,7 @@ class Tasks(Service):
         )
         list_of_labels = list_of_labels if list_of_labels is not None else [None]
         msgs = []
-        for args, kwargs, labels in zip_longest(
+        for args, kwargs, labels in itertools.zip_longest(
             list_of_arguments, list_of_parameters, list_of_labels, fillvalue=None
         ):
             args = args or []
@@ -856,7 +942,7 @@ class Tasks(Service):
         include_modules=None,
         include_data=None,
         requirements=None,
-        **kwargs
+        **kwargs,
     ):
         """
         Creates a new task group from a function and returns an asynchronous
@@ -876,7 +962,7 @@ class Tasks(Service):
             (e.g. `"4Gi"`, `"500MB"`). If no unit is specified it is assumed to be
             in bytes. Default: 2Gi. Maximum: 96Gi.
         :param int maximum_concurrency: The maximum number of tasks to run in
-            parallel. Default: 500. Maximum: 500. If you need higher concurrency
+            parallel. Default: 5. Maximum: 500. If you need higher concurrency
             contact your Descartes Labs customer success representative.
         :param int minimum_concurrency: The minimum number of tasks to run right
             away in parallel. Concurrency is usually scaled up slowly when
@@ -923,7 +1009,7 @@ class Tasks(Service):
             include_modules=include_modules,
             include_data=include_data,
             requirements=requirements,
-            **kwargs
+            **kwargs,
         )
 
         return CloudFunction(
@@ -984,7 +1070,7 @@ class Tasks(Service):
         minimum_seconds=None,
         task_timeout=1800,
         retry_count=0,
-        **kwargs
+        **kwargs,
     ):
         """
         **This method has been deprecated.**  Please use :py:meth:`create_function`
@@ -1008,7 +1094,7 @@ class Tasks(Service):
             (e.g. `"4Gi"`, `"500MB"`). If no unit is specified it is assumed to be
             in bytes. Default: 2Gi. Maximum: 96Gi.
         :param int maximum_concurrency: The maximum number of tasks to run in
-            parallel. Default: 500. Maximum: 500. If you need higher concurrency
+            parallel. Default: 5. Maximum: 500. If you need higher concurrency
             contact your Descartes Labs customer success representative.
         :param int minimum_concurrency: The minimum number of tasks to run right
             away in parallel. Concurrency is usually scaled up slowly when
@@ -1049,7 +1135,7 @@ class Tasks(Service):
             minimum_seconds=minimum_seconds,
             task_timeout=task_timeout,
             retry_count=retry_count,
-            **kwargs
+            **kwargs,
         )
 
     def create_webhook(
@@ -1566,7 +1652,7 @@ class CloudFunction(object):
         :return: A list of all submitted tasks.
         :rtype: list(descarteslabs.client.services.tasks.FutureTask)
         """
-        arguments = zip_longest(args, *iterargs)
+        arguments = itertools.zip_longest(args, *iterargs)
 
         futures = []
         batch = list(itertools.islice(arguments, self.TASK_SUBMIT_SIZE))
