@@ -33,11 +33,11 @@ AOI(geometry=None,
 datetime.datetime(2016, 7, 6, 16, 59, 42, 753476)
 >>> scene.properties.bands.red.resolution  # doctest: +SKIP
 15
->>> arr = scene.ndarray("red green blue", ctx)  # doctest: +SKIP
+>>> arr = scene.ndarray("red green blue", ctx.assign(resolution=120.))  # doctest: +SKIP
 >>> type(arr)  # doctest: +SKIP
 <class 'numpy.ma.core.MaskedArray'>
 >>> arr.shape  # doctest: +SKIP
-(3, 15960, 15696)
+(3, 1995, 1962)
 """
 
 from __future__ import division
@@ -59,6 +59,7 @@ from descarteslabs.common import shapely_support
 
 from . import geocontext
 from . import _download
+from ._helpers import cached_bands_by_product
 from . import _scaling
 
 
@@ -232,7 +233,9 @@ class Scene(object):
             "properties": metadata,
         }
 
-        bands = metadata_client.get_bands_by_id(scene_id)
+        bands = cached_bands_by_product(
+            metadata["properties"]["product"], metadata_client
+        )
         scene = cls(metadata, bands)
 
         return scene, scene.default_ctx()
@@ -441,11 +444,11 @@ class Scene(object):
         -------
         >>> import descarteslabs as dl
         >>> scene, ctx = dl.scenes.Scene.from_id("landsat:LC08:PRE:TOAR:meta_LC80270312016188_v1")  # doctest: +SKIP
-        >>> arr = scene.ndarray("red green blue", ctx)  # doctest: +SKIP
+        >>> arr = scene.ndarray("red green blue", ctx.assign(resolution=120.))  # doctest: +SKIP
         >>> type(arr)  # doctest: +SKIP
         <class 'numpy.ma.core.MaskedArray'>
         >>> arr.shape  # doctest: +SKIP
-        (3, 15960, 15696)
+        (3, 1995, 1962)
         >>> red_band = arr[0]  # doctest: +SKIP
 
         Raises
@@ -457,7 +460,7 @@ class Scene(object):
         NotFoundError
             If a Scene's ID cannot be found in the Descartes Labs catalog
         BadRequestError
-            If the Descartes Labs platform is given invalid parameters
+            If the Descartes Labs Platform is given invalid parameters
         """
         if raster_client is None:
             raster_client = Raster()
@@ -571,6 +574,7 @@ class Scene(object):
         processing_level=None,
         scaling=None,
         data_type=None,
+        nodata=None,
         raster_client=None,
     ):
         """
@@ -620,6 +624,8 @@ class Scene(object):
         data_type : None, str
             Output data type. Please see :meth:`scaling_parameters` for a full
             description of this parameter.
+        nodata : None, number
+            NODATA value for a geotiff file. Will be assigned to any masked pixels.
         raster_client : Raster, optional
             Unneeded in general use; lets you use a specific client instance
             with non-default auth and parameters.
@@ -634,7 +640,7 @@ class Scene(object):
         -------
         >>> import descarteslabs as dl
         >>> scene, ctx = dl.scenes.Scene.from_id("landsat:LC08:PRE:TOAR:meta_LC80270312016188_v1")  # doctest: +SKIP
-        >>> scene.download("red green blue", ctx)  # doctest: +SKIP
+        >>> scene.download("red green blue", ctx.assign(resolution=120.))  # doctest: +SKIP
         "landsat:LC08:PRE:TOAR:meta_LC80270312016188_v1_red-green-blue.tif"
         >>> import os
         >>> os.listdir(".")  # doctest: +SKIP
@@ -656,7 +662,7 @@ class Scene(object):
         NotFoundError
             If a Scene's ID cannot be found in the Descartes Labs catalog
         BadRequestError
-            If the Descartes Labs platform is given invalid parameters
+            If the Descartes Labs Platform is given invalid parameters
         """
         bands = self._bands_to_list(bands)
         scales, dtype = _scaling.scaling_parameters(
@@ -673,6 +679,7 @@ class Scene(object):
             resampler=resampler,
             processing_level=processing_level,
             scales=scales,
+            nodata=nodata,
             raster_client=raster_client,
         )
 
